@@ -7,6 +7,7 @@ using Xunit.Abstractions;
 
 namespace Dotnet.Script.Desktop.Tests
 {
+    [Collection("IntegrationTests")]
     public class CompilationDependencyTests
     {
         public CompilationDependencyTests(ITestOutputHelper testOutputHelper)
@@ -28,7 +29,7 @@ namespace Dotnet.Script.Desktop.Tests
 
         private CompilationDependencyResolver CreateResolver()
         {
-            var resolver = new CompilationDependencyResolver(TestOutputHelper.CreateTestLogFactory());
+            var resolver = new CompilationDependencyResolver(TestOutputHelper.CreateTestLogFactory(), cachePath: null);
             return resolver;
         }
     }
