@@ -11,6 +11,7 @@ using Xunit.Abstractions;
 namespace Dotnet.Script.Tests
 {
     [Collection("IntegrationTests")]
+    // Removed duplicate
     public class ScriptExecutionTests
     {
         public ScriptExecutionTests(ITestOutputHelper testOutputHelper)
@@ -90,7 +91,7 @@ namespace Dotnet.Script.Tests
         {
             var result = ScriptTestRunner.Default.ExecuteFixture(fixture: "CompilationWarning", "--no-cache");
             Assert.True(string.IsNullOrWhiteSpace(result.StandardOut));
-            Assert.Contains("CS1998", result.StandardError, StringComparison.OrdinalIgnoreCase);
+            Assert.Contains("CS0162", result.StandardError, StringComparison.OrdinalIgnoreCase);
         }
 
         [Fact]
@@ -464,14 +465,14 @@ namespace Dotnet.Script.Tests
         [Fact]
         public void ShouldIsolateScriptAssemblies()
         {
-            var (output, _) = ScriptTestRunner.Default.ExecuteFixture("Isolation", "--isolated-load-context");
+            var (output, _) = ScriptTestRunner.Default.ExecuteFixture("Isolation");
             Assert.Contains("2.0.0.0", output);
         }
 
         [Fact]
         public void ShouldSetCurrentContextualReflectionContext()
         {
-            var (output, _) = ScriptTestRunner.Default.ExecuteFixture("CurrentContextualReflectionContext", "--isolated-load-context");
+            var (output, _) = ScriptTestRunner.Default.ExecuteFixture("CurrentContextualReflectionContext");
             Assert.Contains("Dotnet.Script.Core.ScriptAssemblyLoadContext", output);
         }
 
@@ -483,7 +484,7 @@ namespace Dotnet.Script.Tests
             Assert.Equal(0, processResult.ExitCode);
         }
 #endif
-        
+
 #if NET7_0
         [Fact]
         public void ShouldCompileAndExecuteWithWebSdk()
@@ -491,8 +492,8 @@ namespace Dotnet.Script.Tests
             var processResult = ScriptTestRunner.Default.ExecuteFixture("WebApi", "--no-cache");
             Assert.Equal(0, processResult.ExitCode);
         }
-#endif 
-        
+#endif
+
 #if NET8_0
         // .NET 8.0 only works with isolated load context
         [Fact]
@@ -501,8 +502,8 @@ namespace Dotnet.Script.Tests
             var processResult = ScriptTestRunner.Default.ExecuteFixture("WebApi", "--no-cache");
             Assert.Equal(0, processResult.ExitCode);
         }
-#endif 
-        
+#endif
+
         [Fact]
         public void ShouldThrowExceptionWhenSdkIsNotSupported()
         {
