@@ -10,6 +10,7 @@ using Xunit;
 
 namespace Dotnet.Script.Tests
 {
+    [Collection("IntegrationTests")]
     public class ScriptRunnerTests
     {
         [Fact]
@@ -25,7 +26,7 @@ namespace Dotnet.Script.Tests
         private static ScriptRunner CreateScriptRunner()
         {
             var logFactory = TestOutputHelper.CreateTestLogFactory();
-            var scriptCompiler = new ScriptCompiler(logFactory, false);
+            var scriptCompiler = new ScriptCompiler(logFactory, null, false);
             
             return new ScriptRunner(scriptCompiler, logFactory, ScriptConsole.Default);
         }
